pub struct Opts {
pub type_section_suffix: Option<String>,
pub root_package: Option<String>,
pub required_d_versions: Vec<String>,
/* private fields */
}Fields
type_section_suffix: Option<String>Add the specified suffix to the name of the custom section containing the component type.
root_package: Option<String>Choose root package other than wit to nest everything under.
required_d_versions: Vec<String>A series of D versions that all the generated bindings will be gated behind.
Implementations